@@ -23,6 +23,7 @@ from patchwork.steps.GenerateCodeRepositoryEmbeddings.GenerateCodeRepositoryEmbe
     GenerateCodeRepositoryEmbeddings,
 )
 from patchwork.steps.GenerateEmbeddings.GenerateEmbeddings import GenerateEmbeddings
+from patchwork.steps.JoinList.JoinList import JoinList
 from patchwork.steps.LLM.LLM import LLM
 from patchwork.steps.ModifyCode.ModifyCode import ModifyCode
 from patchwork.steps.PR.PR import PR
@@ -35,7 +36,6 @@ from patchwork.steps.ScanDepscan.ScanDepscan import ScanDepscan
 from patchwork.steps.ScanSemgrep.ScanSemgrep import ScanSemgrep
 from patchwork.steps.SimplifiedLLM.SimplifiedLLM import SimplifiedLLM
 from patchwork.steps.SlackMessage.SlackMessage import SlackMessage
-from patchwork.steps.JoinList.JoinList import JoinList
 
 __all__ = [
     "AnalyzeImpact",
@@ -67,5 +67,5 @@ __all__ = [
     "ScanSemgrep",
     "SimplifiedLLM",
     "SlackMessage",
-    "JoinList"
+    "JoinList",
 ]
